@@ -91,6 +91,11 @@ class Switchport(NCSObject):
         self.mode.mode_choice.trunk.vlan_list = LeafList(str)
         self.mode.mode_choice.default = Container()
 
+class IPv6Subnet(NCSObject):
+
+    def initialize_model(self):
+        self.prefix = Leaf(str)
+
 class Network(NCSObject):
 
     _path = "/config/services/network"
@@ -112,7 +117,7 @@ class Network(NCSObject):
         self.layer3.vrf = Leaf(str)
         self.layer3.primary_ipv4_subnet = Leaf(str)
         self.layer3.secondary_ipv4_subnets = LeafList(str)
-        self.layer3.ipv6_subnet = LeafList(str)
+        self.layer3.ipv6_subnet = List(IPv6Subnet, keyattr="prefix")
         self.layer3.dhcp_relay_servers = Leaf(str)
         self.layer3.ingress_acl = Leaf(str)
         self.layer3.egress_acl = Leaf(str)
